@@ -3,7 +3,10 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 from builtins import str
-from future import standard_library
+import warnings
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore")
+    from future import standard_library
 standard_library.install_aliases()
 from builtins import object
 from typing import Any
@@ -14,7 +17,7 @@ from typing import Optional
 class DatastoreOperation(object):
     def __init__(self, name     , done      ,
                  metadata                           = None,
-                 error                 = None,
+                 error                           = None,
                  response                           = None)        :
         self.name = name
         self.done = done
